Learn R Programming

smoothmest (version 0.1-3)

pdens: Auxiliary functions for pitman

Description

Auxiliary functions for pitman.

Usage

pdens(z, x, dfunction, ...)
  sdens(z, x, dfunction, ...)
  dens(x, dfunction, ...)

Arguments

z

numeric vector.

x

numeric vector.

dfunction

a density function defining the distribution for which the Pitman estimator is computed.

...

further arguments to be passed on to the density function dfunction.

Value

Numeric value (dens) or vector.

Details

dens

product of density values at x.

pdens

vector of z*dens(x-z).

sdens

vector of dens(x-z).

References

Pitman, E.J. (1939) The estimation of the location and scale parameters of a continuous population of any given form. Biometrika 30, 391-421.

See Also

pitman

Examples

Run this code
# NOT RUN {
  dens(1:5,dcauchy)
  pdens(1:5,0,dcauchy)
  sdens(1:5,0:2,dcauchy)
# }

Run the code above in your browser using DataLab