numeric. Borderline value of central Gaussian part of the
distribution. The default values refers to a 20% contamination
neighborhood of the Gaussian distribution.
mu
numeric. distribution mean.
sigma
numeric. Distribution scale (sigma=1 defines the
distribution in standard form, with standard Gaussian centre).
n
integer. Number of random values to be generated.
Value
dhuber gives out a vector of density values.
edhuber gives out a list with components val (density
values) and eps (contamination proportion).
rhuber gives out a vector of random numbers generated by
Huber's least favourable distribution.
Details
dhuber:
density.
edhuber:
density, and computes the contamination proportion
corresponding to k.
rhuber:
random number generation.
References
Huber, P. J. and Ronchetti, E. (2009) Robust Statistics (2nd
ed.). Wiley, New York.