powered by
Auxiliary functions for pitman.
pitman
pdens(z, x, dfunction, ...) sdens(z, x, dfunction, ...) dens(x, dfunction, ...)
numeric vector.
a density function defining the distribution for which the Pitman estimator is computed.
further arguments to be passed on to the density function dfunction.
dfunction
Numeric value (dens) or vector.
dens
product of density values at x.
x
vector of z*dens(x-z).
z*dens(x-z)
vector of dens(x-z).
dens(x-z)
Pitman, E.J. (1939) The estimation of the location and scale parameters of a continuous population of any given form. Biometrika 30, 391-421.
# NOT RUN { dens(1:5,dcauchy) pdens(1:5,0,dcauchy) sdens(1:5,0:2,dcauchy) # }
Run the code above in your browser using DataLab